# Table of Contents

- [setting-up-custom-smtp-server-for-email-notifications](<./setting-up-custom-smtp-server-for-email-notifications.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Setting Up a Custom SMTP Server for Email Notifications](<./Setting-Up-a-Custom-SMTP-Server-for-Email-Notifications.md>)
  - [Overview](<./Setting-Up-a-Custom-SMTP-Server-for-Email-Notifications/Overview.md>)
  - [Authentication](<./Setting-Up-a-Custom-SMTP-Server-for-Email-Notifications/Authentication.md>)
  - [Configuring a Custom SMTP Server](<./Setting-Up-a-Custom-SMTP-Server-for-Email-Notifications/Configuring-a-Custom-SMTP-Server.md>)
  - [Was this page helpful?](<./Setting-Up-a-Custom-SMTP-Server-for-Email-Notifications/Was-this-page-helpful.md>)
